--
-- Script to create instant3Dhub booster tables
--

SET statement_timeout = 0;
SET client_encoding = 'UTF8';
SET standard_conforming_strings = on;
SET check_function_bodies = false;
SET client_min_messages = warning;

SET search_path = i3dh, i3dhBooster, pg_catalog, extensions;

SET default_tablespace = '';

SET default_with_oids = false;

create schema if not exists "i3dhBooster";

ALTER SCHEMA "i3dhBooster" OWNER TO i3dhub;

CREATE TABLE IF NOT EXISTS "i3dhBooster".booster_version
(
    name text not null primary key,
    version int not null
);

ALTER TABLE "i3dhBooster".booster_version OWNER TO i3dhub;


CREATE TABLE IF NOT EXISTS "i3dhBooster".hub_files
(
  path       text   not null,
  version    text   not null,
  size_bytes bigint default 0,
  constraint hubfiles_pkey primary key (path)
);

ALTER TABLE "i3dhBooster".hub_files OWNER TO i3dhub;


CREATE TABLE IF NOT EXISTS "i3dhBooster".resource_local
(
  res_id        bigserial not null UNIQUE,
  version       text      default '',
  size_bytes    bigint    default 0,
  source_uri    text      default '',
  booster_state integer   default 1,

  CONSTRAINT fk_resource
        FOREIGN KEY (res_id) REFERENCES i3dh.resource(id)
        ON UPDATE CASCADE
        ON DELETE CASCADE
);

ALTER TABLE "i3dhBooster".resource_local OWNER TO i3dhub;


CREATE TABLE IF NOT EXISTS "i3dhBooster".resource_children
(
  parent_id bigserial NOT NULL, 
  child_id  bigserial NOT NULL, 

  FOREIGN KEY (parent_id) REFERENCES i3dh.resource(id)
    ON UPDATE CASCADE
	ON DELETE CASCADE,
  FOREIGN KEY (child_id) REFERENCES i3dh.resource(id)
    ON UPDATE CASCADE
	ON DELETE CASCADE,
  PRIMARY KEY (parent_id, child_id)
);

ALTER TABLE "i3dhBooster".resource_children OWNER TO i3dhub;


CREATE TABLE IF NOT EXISTS "i3dhBooster".session
(
  id serial    not null PRIMARY KEY,
  id_text text not null
);

ALTER TABLE "i3dhBooster".session OWNER TO i3dhub;


CREATE TABLE IF NOT EXISTS "i3dhBooster".session_resources
(
  session_id bigserial not null,
  res_id     bigserial not null,

  FOREIGN KEY (session_id) REFERENCES "i3dhBooster".session(id)
    ON UPDATE CASCADE
	ON DELETE CASCADE,
  FOREIGN KEY (res_id) REFERENCES i3dh.resource(id)
    ON UPDATE CASCADE
	ON DELETE CASCADE,
  PRIMARY KEY (session_id, res_id)
);

ALTER TABLE "i3dhBooster".session_resources OWNER TO i3dhub;


CREATE TABLE IF NOT EXISTS "i3dhBooster".resource_children_closure
(
  parent_id bigserial not null, 
  child_id  bigserial not null, 
  depth     integer   not null,

  FOREIGN KEY (parent_id) REFERENCES i3dh.resource(id)
    ON UPDATE CASCADE
	ON DELETE CASCADE,
  FOREIGN KEY (child_id) REFERENCES i3dh.resource(id)
    ON UPDATE CASCADE
	ON DELETE CASCADE,
  PRIMARY KEY (parent_id, child_id, depth)
);

ALTER TABLE "i3dhBooster".resource_children_closure OWNER TO i3dhub;

CREATE OR REPLACE FUNCTION "i3dhBooster".closure_relation_add() RETURNS TRIGGER
    LANGUAGE plpgsql AS
$$
BEGIN
    INSERT INTO "i3dhBooster".resource_children_closure(parent_id, child_id, depth)
    SELECT p.parent_id, c.child_id, p.depth+c.depth+1
    FROM "i3dhBooster".resource_children_closure p, "i3dhBooster".resource_children_closure c
    WHERE p.child_id = NEW.parent_id AND c.parent_id = NEW.child_id
    ON CONFLICT(parent_id, child_id, depth) DO NOTHING;
    RETURN NULL;
END;
$$;

DROP TRIGGER IF EXISTS relation_add ON "i3dhBooster".resource_children;
CREATE TRIGGER relation_add AFTER INSERT ON "i3dhBooster".resource_children
    FOR EACH ROW EXECUTE PROCEDURE "i3dhBooster".closure_relation_add();


CREATE OR REPLACE FUNCTION "i3dhBooster".closure_self_add() RETURNS TRIGGER
    LANGUAGE plpgsql AS
$$
BEGIN
    INSERT INTO "i3dhBooster".resource_children_closure(parent_id, child_id, depth)
    VALUES (NEW.id, NEW.id, 0)
    ON CONFLICT(parent_id, child_id, depth) DO NOTHING;
    RETURN NULL;
END;
$$;

DROP TRIGGER IF EXISTS self_add ON i3dh.resource;
CREATE TRIGGER self_add AFTER INSERT ON i3dh.resource
    FOR EACH ROW EXECUTE PROCEDURE "i3dhBooster".closure_self_add();
