create or replace function keys.notify_key_change()
    returns trigger
as
$body$
begin
    perform pg_notify('key_changed',
                      json_build_object(
                              'operation', tg_op,
                              'entry', row_to_json(new)
                          )::text
        );
    return new;
end
$body$
    language plpgsql;

drop trigger if exists keys_change on keys.active_keys;
create trigger keys_change
    after insert
    on keys.active_keys
    for each row
execute procedure keys.notify_key_change();

create or replace function keys.insert_key(p_key varchar)
    returns void
as
$body$
begin
    insert into keys.active_keys(key)
    values (p_key);
end;
$body$
    language plpgsql;

create or replace function keys.get_current_active(p_n int)
    returns table
            (
                r_created timestamptz,
                r_key     text
            )
as
$body$
begin
    return query (
        select limited.created, limited.key
        from (select created, key
              from keys.active_keys
              order by created desc
              limit p_n) as limited
        order by limited.created asc
    );
end;
$body$
    language plpgsql;

create or replace function keys.delete_keys_keep_n(p_n int)
    returns void
as
$body$
begin
    delete
    from keys.active_keys
    where id in (
        select id
        from keys.active_keys
        order by created desc
        offset p_n
    );
end;
$body$
    language plpgsql;
