-- FUNCTION: l3d.check_existing_cache_func()

-- DROP FUNCTION l3d.check_existing_cache_func();

CREATE OR REPLACE FUNCTION l3d.check_existing_cache_func()
    RETURNS trigger
    LANGUAGE 'plpgsql'
    COST 100
    VOLATILE NOT LEAKPROOF 
    
AS $BODY$

	DECLARE c_id bigint;
BEGIN
IF TG_OP = 'INSERT' THEN
	
    SELECT id INTO c_id FROM l3d.cache 
               WHERE l3d.cache.uuid = NEW.uuid
               AND l3d.cache.ext_cache_id0 = NEW.ext_cache_id0
               AND l3d.cache.ext_cache_id1 = NEW.ext_cache_id1
               AND l3d.cache.active = true;
    IF FOUND THEN
    	PERFORM l3d.deactivate_cache(c_id);
    	
	-- RAISE NOTICE 'TRIGGER called on %', TG_TABLE_NAME;
    END IF;
END IF;
RETURN NEW;
END;

$BODY$;

ALTER FUNCTION l3d.check_existing_cache_func()
    OWNER TO i3dhub;
	
	
	

-- FUNCTION: l3d.update_index_references_func()

-- DROP FUNCTION l3d.update_index_references_func();

CREATE OR REPLACE FUNCTION l3d.update_index_references_func()
    RETURNS trigger
    LANGUAGE 'plpgsql'
    COST 100
    VOLATILE NOT LEAKPROOF 
    
AS $BODY$

	DECLARE c_id_old bigint =NULL;
	DECLARE c_id_new bigint = NULL;
	DECLARE c_uuid character varying;
	DECLARE c_cid0 integer;
	DECLARE c_cid1 integer;
BEGIN
IF TG_OP = 'INSERT' THEN
	
	c_uuid:= NEW.uuid;
	c_cid0:= NEW.ext_cache_id0;
	c_cid1:= NEW.ext_cache_id1;
	
    SELECT max(id) INTO c_id_old FROM l3d.cache 
               WHERE l3d.cache.uuid = c_uuid
               AND l3d.cache.ext_cache_id0 = c_cid0
               AND l3d.cache.ext_cache_id1 = c_cid1
               AND l3d.cache.active = false
			 ;
	 SELECT id INTO c_id_new FROM l3d.cache 
               WHERE l3d.cache.uuid = c_uuid
               AND l3d.cache.ext_cache_id0 = c_cid0
               AND l3d.cache.ext_cache_id1 = c_cid1
               AND l3d.cache.active = true;		
    IF c_id_old IS NOT NULL THEN
    	PERFORM l3d.upd_index_referenced_cache(c_id_old,c_id_new);
    	
	-- RAISE NOTICE 'TRIGGER called on %', TG_TABLE_NAME;
    END IF;
END IF;
RETURN NEW;

END;

$BODY$;

ALTER FUNCTION l3d.update_index_references_func()
    OWNER TO i3dhub;	


CREATE TRIGGER check_existing_cache_trigger
BEFORE INSERT 
ON l3d.cache
FOR EACH ROW
EXECUTE PROCEDURE l3d.check_existing_cache_func();


CREATE TRIGGER update_index_references_trigger
    AFTER INSERT
    ON l3d.cache
    FOR EACH ROW
    EXECUTE PROCEDURE l3d.update_index_references_func();
