-- View: l3d.auxnode_data

-- DROP VIEW l3d.auxnode_data;

CREATE OR REPLACE VIEW l3d.auxnode_data AS
 SELECT t."id", t."nodeId", t."cache_id", t."label", 
    array_agg(DISTINCT t."Attributes") AS "Attributes", 
    array_agg(DISTINCT t."Properties") AS "Properties"
   FROM ( SELECT an."id", an."ext_aux_node_id" AS "nodeId", an."cache_id", 
            an."label", ant."name", 
            ((('{"name":"'::text || aat."key"::text) || '", "value": "'::text) || aat."value") || '"}'::text AS "Attributes", 
            ((('{"name":"'::text || avn."name"::text) || '", "value": "'::text) || replace((COALESCE(av."value_str", av."value_num"::text))::text,'"','')) || '"}'::text AS "Properties"
           FROM l3d.aux_node an, l3d.aux_node_type ant, 
            l3d.aux_attributes aat, l3d.aux_value av, 
            l3d.aux_value_name avn
          WHERE ant."id" = an."aux_node_type_id" AND aat."aux_node_id" = an."id" AND av."aux_node_id" = an."id" AND av."aux_value_name_id" = avn."id") t
  GROUP BY t."id", t."nodeId", t."cache_id", t."label", t."name";

ALTER TABLE l3d.auxnode_data
    OWNER TO i3dhub;





-- View: l3d.auxnode_refs

-- DROP VIEW l3d.auxnode_refs;

CREATE OR REPLACE VIEW l3d.auxnode_refs AS
 SELECT t."id", t."cache_id", array_agg(t.refs) AS refs
   FROM ( SELECT an1."id", an1."cache_id", 
            ('{"name":"nodes","value":['::text || string_agg(an2."ext_aux_node_id"::text, ','::text)) || ']}'::text AS refs
           FROM l3d.aux_node an1, l3d.aux_node_to_aux_node ansp, 
            l3d.aux_node an2
          WHERE ansp."succ_id" = an2."id" AND ansp."pred_id" = an1."id"
          GROUP BY an1."id", an1."cache_id") t
  GROUP BY t."id", t."cache_id";

ALTER TABLE l3d.auxnode_refs
    OWNER TO i3dhub;


-- View: l3d.auxnode_stats

-- DROP VIEW l3d.auxnode_stats;

CREATE OR REPLACE VIEW l3d.auxnode_stats AS
 SELECT d."id", array_agg(d.stats) AS stats
   FROM ( SELECT t."pred_id" AS "id", 
            (((('{ "name":"'::text || t.name::text) || '","count":'::text) || t.count::text) || '}'::text)::json AS stats
           FROM ( SELECT asp."pred_id", ant."name" AS name, 
                    count(asp."succ_id") AS count
                   FROM l3d.aux_node_to_aux_node asp, 
                    l3d.aux_node an, l3d.aux_node_type ant
                  WHERE asp."succ_id" = an."id" AND an."aux_node_type_id" = ant."id"
                  GROUP BY ant."name", asp."pred_id") t) d
  GROUP BY d."id";

ALTER TABLE l3d.auxnode_stats
    OWNER TO i3dhub;
	
	
--
-- view on auxnode properties
--
CREATE OR REPLACE VIEW l3d.auxnode_prop AS
 SELECT t."id",
    t."nodeId",
    t."cache_id",
    t."label",
    array_append(array_agg(DISTINCT t."Properties") , '{"name":"pmiType","value":"'|| t."name"||'"}')  AS "Properties"
   FROM ( SELECT an."id",
            an."ext_aux_node_id" AS "nodeId",
            an."cache_id",
            an."label",
            ant."name",
            ((('{"name":"'::text || avn."name"::text) || '", "value": "'::text) || replace(COALESCE(av."value_str", av."value_num"::text::character varying)::text, '"'::text, ''::text)) || '"}'::text AS "Properties"
           FROM l3d.aux_node an,
            l3d.aux_node_type ant,
            l3d.aux_value av,
            l3d.aux_value_name avn
          WHERE ant."id" = an."aux_node_type_id" AND av."aux_node_id" = an."id" AND av."aux_value_name_id" = avn."id") t
  GROUP BY t."id", t."nodeId", t."cache_id", t."label", t."name";

ALTER TABLE l3d.auxnode_prop
    OWNER TO i3dhub;
		
