-- FUNCTION: l3d.ins_index_cache(bigint, bigint, character varying, character varying, character varying, integer, character varying, integer, json)

-- DROP FUNCTION l3d.ins_index_cache(bigint, bigint, character varying, character varying, character varying, integer);


CREATE OR REPLACE FUNCTION l3d.ins_index_cache(
	
	p_l3dcache_id bigint,
	p_url character varying,
	p_state character varying,
	p_groupp character varying,
	p_bytes integer,
	p_l3dgenver character varying, 
	p_datalayoutver integer, 
	p_originalrequest json)
RETURNS void
    LANGUAGE 'plpgsql'
    COST 100
    VOLATILE 
AS $BODY$

 BEGIN 
 
	
 INSERT INTO l3d.index_cache(url,state,transcoder_group,bytes,cache_id,l3dgen_version,data_layout_version,original_request)
 	VALUES (p_url,p_State,p_Groupp,p_Bytes,p_l3dcache_id,p_l3dgenver,p_datalayoutver,p_originalrequest);
	
	
 END; 

$BODY$;

ALTER FUNCTION l3d.ins_index_cache(bigint, character varying, character varying, character varying, integer, character varying, integer, json)
    OWNER TO i3dhub;


-- FUNCTION: l3d.ins_index_stats(bigint, timestamp without time zone, integer, timestamp without time zone, timestamp without time zone, timestamp without time zone, timestamp without time zone, bigint)

-- DROP FUNCTION l3d.ins_index_stats(bigint, timestamp without time zone, integer, timestamp without time zone, timestamp without time zone, timestamp without time zone, timestamp without time zone, bigint);

CREATE OR REPLACE FUNCTION l3d.ins_index_stats(
	p_queueddate timestamp with time zone,
	p_numreads integer,
	p_lastmodifieddate timestamp with time zone,
	p_lastreaddate timestamp with time zone,
	p_processingstartdate timestamp with time zone,
	p_processingenddate timestamp with time zone,
	p_l3dcache_id bigint)
RETURNS void
    LANGUAGE 'plpgsql'
    COST 100
    VOLATILE 
AS $BODY$

 BEGIN 
	INSERT INTO l3d.index_stats(queued_date,num_reads,last_modified_date,last_read_date,processing_start_date,processing_end_date,cache_id)
 	VALUES (p_queueddate,p_numreads,p_lastmodifieddate,p_lastreaddate,p_processingstartdate,p_processingenddate,p_l3dcache_id) ; 
 END; 
$BODY$;

ALTER FUNCTION l3d.ins_index_stats(timestamp with time zone, integer, timestamp with time zone, timestamp with time zone, timestamp with time zone, timestamp with time zone, bigint)
    OWNER TO i3dhub;


-- FUNCTION: l3d.ins_index_properties(bigint, json, bigint, character varying)

-- DROP FUNCTION l3d.ins_index_properties(bigint, json, bigint, character varying);

CREATE OR REPLACE FUNCTION l3d.ins_index_properties(
	p_properties json,
	p_l3dcache_id bigint)
RETURNS void
    LANGUAGE 'plpgsql'
    COST 100
    VOLATILE 
AS $BODY$

 BEGIN 
INSERT INTO l3d.index_properties(properties,cache_id)
 VALUES (p_properties,p_l3dcache_id) ; 
 END; 
$BODY$;

ALTER FUNCTION l3d.ins_index_properties( json, bigint)
    OWNER TO i3dhub;



-- FUNCTION: l3d.ins_index_source(character varying, character varying, character varying, character varying, character varying[], character varying, bigint);

-- DROP FUNCTION l3d.ins_index_source(character varying, character varying, character varying, character varying, character varying[], character varying, bigint);

CREATE OR REPLACE FUNCTION l3d.ins_index_source(
	p_uri character varying,
	p_url character varying,
	p_auth_url character varying,
	p_property character varying,
	p_etag character varying,
	p_mimeType character varying[],
	p_cache_id bigint)
RETURNS void
    LANGUAGE 'plpgsql'
    COST 100
    VOLATILE 
AS $BODY$

 BEGIN 
INSERT INTO l3d.index_source(uri, url, auth_url, property, e_tag, cache_id, mime_type)
 VALUES (p_uri, p_url, p_auth_url, p_property, p_etag, p_cache_id, p_mimeType);
 END; 
$BODY$;

ALTER FUNCTION l3d.ins_index_source(character varying, character varying, character varying, character varying, character varying, character varying[], bigint)
    OWNER TO i3dhub;
	
	
-- FUNCTION: l3d.upd_index_source(character varying, character varying, character varying, character varying, character varying, character varying[], bigint)

-- DROP FUNCTION l3d.upd_index_source(character varying, character varying, character varying, character varying, character varying, character varying[], bigint)

CREATE OR REPLACE FUNCTION l3d.upd_index_source(
	p_uri character varying,
	p_url character varying,
	p_auth_url character varying,
	p_property character varying,
	p_etag character varying,
	p_mimeType character varying[],
	p_cache_id bigint)
RETURNS void
    LANGUAGE 'plpgsql'
    COST 100
    VOLATILE 

AS $BODY$
 BEGIN 
	UPDATE l3d.index_source SET 
		uri = coalesce(p_uri,uri),
		url = coalesce(p_url,url), 
		auth_url = coalesce(p_auth_url,auth_url),
		property = coalesce(p_property,property),
		e_tag = coalesce(p_etag,e_tag),
		mime_type = coalesce(p_mimeType,mime_type)
 	WHERE cache_id = p_cache_id;
 END; 
$BODY$;

ALTER FUNCTION l3d.upd_index_source(character varying, character varying, character varying, character varying, character varying, character varying[], bigint)
    OWNER TO i3dhub;



-- FUNCTION: l3d.ins_index_data

-- DROP FUNCTION l3d.ins_index_data;

CREATE OR REPLACE FUNCTION l3d.ins_index_data(
	p_uuid character varying,
	p_cid0 integer,
	p_cid1 integer,
	p_c_url character varying,
	p_c_state character varying,
	p_c_groupp character varying,
	p_c_bytes integer,
	p_c_l3dgenver character varying, 
	p_c_datalayoutver integer, 
	p_c_originalrequest json,
	p_st_queueddate timestamp with time zone,
	p_st_numreads integer,
	p_st_lastmodifieddate timestamp with time zone,
	p_st_lastreaddate timestamp with time zone,
	p_st_processingstartdate timestamp with time zone,
	p_st_processingenddate timestamp with time zone,
	p_p_properties json,
	p_src_uri character varying,
	p_src_url character varying,
	p_src_auth_url character varying,
	p_src_property character varying,
	p_src_mimetype character varying[],
	p_src_etag character varying)
RETURNS void
    LANGUAGE 'plpgsql'
    COST 100
    VOLATILE 
AS $BODY$

	DECLARE cacheId bigint = NULL;
    BEGIN 

        cacheId := nextval(pg_get_serial_sequence('l3d.cache', 'id'));  

        IF NOT exists(select * from l3d.index_cache WHERE cache_id = cacheId) THEN
          -- insert indxl3d_cache data
          PERFORM  l3d.ins_index_cache(cacheId,p_c_url,p_c_state,p_c_groupp,p_c_bytes, p_c_l3dgenver, p_c_datalayoutver, p_c_originalrequest);            
        END IF;

        IF NOT exists(select * from l3d.index_stats WHERE cache_id = cacheId) THEN
          -- insert indxl3d_stats data
          PERFORM l3d.ins_index_stats(p_st_queueddate,p_st_numreads,p_st_lastmodifieddate,p_st_lastreaddate,p_st_processingstartdate,p_st_processingenddate,cacheId);
        END IF;

        IF NOT exists(select * from l3d.index_properties WHERE cache_id = cacheId) THEN
          -- insert indxl3d_properties data 
          PERFORM  l3d.ins_index_properties(p_p_properties,cacheId);              
        END IF;

        IF NOT exists(select * from l3d.index_source WHERE cache_id = cacheId) THEN
          -- insert indxl3d_properties data 
          PERFORM  l3d.ins_index_source(p_src_uri,p_src_url,p_src_auth_url,p_src_property,p_src_etag,p_src_mimeType,cacheId);
        END IF;

        INSERT INTO l3d.cache(id, uuid,ext_cache_id0,ext_cache_id1,active) VALUES (cacheId, p_uuid,p_cid0,p_cid1,true);  

    END; 

$BODY$;

ALTER FUNCTION l3d.ins_index_data(character varying, integer, integer, character varying, character varying, character varying, integer, character varying, integer, json, timestamp with time zone, integer, timestamp with time zone, timestamp with time zone, timestamp with time zone, timestamp with time zone, json, character varying, character varying, character varying, character varying, character varying[], character varying)
    OWNER TO i3dhub;
	
-- FUNCTION: l3d.upd_cache( bigint,character varying,character varying,character varying, character varying, character varying, integer)

-- DROP FUNCTION l3d.upd_cache( bigint,character varying,character varying,character varying, character varying, character varying, integer);

drop function if exists l3d.upd_index_cache(character varying,integer,integer,character varying,character varying,character varying,integer,character varying,integer);

CREATE OR REPLACE FUNCTION l3d.upd_index_cache(
	p_uuid character varying,
	p_cid0 integer,
	p_cid1 integer,
	p_url character varying,
	p_state character varying,
	p_groupp character varying,
	p_bytes bigint,
    	p_l3dgen_version character varying, 
    	p_data_layout_version integer)
RETURNS void
    LANGUAGE 'plpgsql'
    COST 100
    VOLATILE 
AS $BODY$
	DECLARE cacheId bigint = NULL;
 BEGIN 
 	
	SELECT l3d.get_cache(p_uuid,p_cid0,p_cid1) INTO cacheId;
	UPDATE l3d.index_cache SET url = coalesce(p_url,url),state = coalesce(p_State,state),transcoder_group = coalesce(p_Groupp,transcoder_group),bytes = coalesce( (p_Bytes / (1024))::integer ,bytes), l3dgen_version = coalesce(p_l3dgen_version, l3dgen_version), data_layout_version = coalesce(p_data_layout_version, data_layout_version)
 	WHERE cache_id = cacheId;
 END; 
$BODY$;

ALTER FUNCTION l3d.upd_index_cache( character varying,
	 integer,
	 integer,
	 character varying,
	 character varying,
	 character varying,
	 bigint,
     character varying,
     integer)
    OWNER TO i3dhub;
	
	

-- FUNCTION: l3d.upd_index_stats(character varying, integer, integer, timestamp with time zone, integer, timestamp with time zone, timestamp with time zone, timestamp with time zone, timestamp with time zone)

-- DROP FUNCTION l3d.upd_index_stats(character varying, integer, integer, timestamp with time zone, integer, timestamp with time zone, timestamp with time zone, timestamp with time zone, timestamp with time zone);

CREATE OR REPLACE FUNCTION l3d.upd_index_stats(
	p_uuid character varying,
	p_cid0 integer,
	p_cid1 integer,
	p_queueddate timestamp with time zone,
	p_numreads integer,
	p_lastmodifieddate timestamp with time zone,
	p_lastreaddate timestamp with time zone,
	p_processingstartdate timestamp with time zone,
	p_processingenddate timestamp with time zone)
RETURNS void
    LANGUAGE 'plpgsql'
    COST 100
    VOLATILE 
AS $BODY$

	DECLARE cacheId bigint = NULL;
  BEGIN
  	SELECT l3d.get_cache(p_uuid,p_cid0,p_cid1) INTO cacheId;
	UPDATE l3d.index_stats SET queued_date = coalesce(p_QueuedDate,queued_date),num_reads = num_reads + coalesce(p_NumReads,0),last_modified_date = coalesce(p_LastModifiedDate,last_modified_date),last_read_date = coalesce(p_LastReadDate,last_read_date),processing_start_date = coalesce(p_ProcessingStartDate,processing_start_date),processing_end_date = coalesce(p_ProcessingEndDate,processing_end_date)
 	WHERE cache_id = cacheId;
 END; 

$BODY$;

ALTER FUNCTION l3d.upd_index_stats(character varying, integer, integer, timestamp with time zone, integer, timestamp with time zone, timestamp with time zone, timestamp with time zone, timestamp with time zone)
    OWNER TO i3dhub;


-- FUNCTION: l3d.get_index_stats_lastmodifieddata( bigint,character varying,character varying,refcursor)

-- DROP FUNCTION l3d.get_index_stats_lastmodifieddata( bigint,character varying,character varying,refcursor);


CREATE OR REPLACE FUNCTION l3d.get_index_stats_lastmodifieddata(
	p_uuid character varying,
	p_cid0 integer,
	p_cid1 integer,
	ocursor refcursor)
RETURNS void
    LANGUAGE 'plpgsql'
    COST 100
    VOLATILE 
AS $BODY$
DECLARE cacheId bigint = NULL;
 BEGIN 
 SELECT l3d.get_cache(p_uuid,p_cid0,p_cid1) INTO cacheId;
   
   OPEN oCursor FOR Select 
	last_modified_date
	from 
	l3d.index_stats
	WHERE cache_id = cacheId;


 END; 
$BODY$;

ALTER FUNCTION l3d.get_index_stats_lastmodifieddata( character varying,integer,integer,refcursor)
    OWNER TO i3dhub;	
	
	

-- FUNCTION: l3d.upd_index_properties(bigint,  character varying, character varying,json)

-- DROP FUNCTION l3d.upd_index_properties(bigint,  character varying, character varying,json);
CREATE OR REPLACE FUNCTION l3d.upd_index_properties(
	p_cid integer,
	p_properties json)
RETURNS void
    LANGUAGE 'plpgsql'
    COST 100
    VOLATILE 
AS $BODY$


 BEGIN 
 	
	UPDATE l3d.index_properties SET properties = coalesce(p_Properties,properties)
 	WHERE cache_id = p_cid;
 END; 

$BODY$;

ALTER FUNCTION l3d.upd_index_properties(integer, json)
    OWNER TO i3dhub;



-- FUNCTION: l3d.get_index_caches_by_provider(character varying, refcursor)

-- DROP FUNCTION l3d.get_index_caches_by_provider(character varying, refcursor);

CREATE OR REPLACE FUNCTION l3d.get_index_caches_by_provider(
	p_uuid character varying,
	ocursor refcursor)
RETURNS void
    LANGUAGE 'plpgsql'
    COST 100
    VOLATILE 
AS $BODY$


 BEGIN 
   
   OPEN oCursor FOR SELECT
						ext_cache_id0,
						ext_cache_id1,
						properties,
						state,
						data_layout_version,
						original_request,
						bytes,
						uri
	FROM (
    		SELECT
      			*
    		FROM
      			l3d.cache cache
    		WHERE
      			cache.active = TRUE
      			AND cache.uuid = p_uuid
  		) c
  	INNER JOIN l3d.index_properties p ON (c.id = p.cache_id)
  	INNER JOIN l3d.index_cache i ON (i.cache_id = p.cache_id)
  	INNER JOIN l3d.index_source s ON (s.cache_id = p.cache_id);
	
 	END; 

$BODY$;

ALTER FUNCTION l3d.get_index_caches_by_provider(character varying, refcursor)
    OWNER TO i3dhub;
	




-- FUNCTION: l3d.upd_index_referenced_cache(bigint,bigint)

-- DROP FUNCTION l3d.upd_index_referenced_cache(bigint,bigint);	
CREATE OR REPLACE FUNCTION l3d.upd_index_referenced_cache(
	p_cid_old bigint,
	p_cid_new bigint
	)
RETURNS void
    LANGUAGE 'plpgsql'
    COST 100
    VOLATILE 
AS $BODY$

  BEGIN

	IF NOT exists(select * from l3d.index_cache WHERE cache_id = p_cid_new) THEN
		    UPDATE l3d.index_cache SET cache_id = p_cid_new WHERE cache_id = p_cid_old;            
		END IF;

	    IF NOT exists(select * from l3d.index_stats WHERE cache_id = p_cid_new) THEN
			UPDATE l3d.index_stats SET cache_id = p_cid_new WHERE cache_id = p_cid_old;
	    END IF;

	    IF NOT exists(select * from l3d.index_properties WHERE cache_id = p_cid_new) THEN
		UPDATE l3d.index_properties SET cache_id = p_cid_new WHERE cache_id = p_cid_old;              
	    END IF;

	    IF NOT exists(select * from l3d.index_source WHERE cache_id = p_cid_new) THEN
			UPDATE l3d.index_source SET cache_id = p_cid_new WHERE cache_id = p_cid_old;
	    END IF;  	
    
 END; 

$BODY$;

ALTER FUNCTION l3d.upd_index_referenced_cache(bigint,bigint)
    OWNER TO i3dhub;	
	
	
	


-- FUNCTION: l3d.get_index_caches_waitingtime(refcursor)

-- DROP FUNCTION l3d.get_index_caches_waitingtime(refcursor);

CREATE OR REPLACE FUNCTION l3d.get_index_caches_waitingtime(
	ocursor refcursor)
RETURNS void
    LANGUAGE 'plpgsql'
    COST 100
    VOLATILE 
AS $BODY$

BEGIN
OPEN ocursor FOR 
	SELECT (c.uuid || '/'|| c.ext_cache_id0 || '/' ||c.ext_cache_id1) as "id" , (EXTRACT (EPOCH FROM  (processing_start_date - queued_date))) as "key", cache_id as "value"
	FROM l3d.index_stats as s, l3d.cache as c
	WHERE s.cache_id = c.id
	
	order by "key";
	
END;

$BODY$;

ALTER FUNCTION l3d.get_index_caches_waitingtime(refcursor)
    OWNER TO i3dhub;

	
-- FUNCTION: l3d.get_index_caches_readcounts(refcursor)

-- DROP FUNCTION l3d.get_index_caches_readcounts(refcursor);

CREATE OR REPLACE FUNCTION l3d.get_index_caches_readcounts(
	ocursor refcursor)
RETURNS void
    LANGUAGE 'plpgsql'
    COST 100
    VOLATILE 
AS $BODY$

BEGIN
OPEN ocursor FOR 
	SELECT  (c.uuid || '/'|| c.ext_cache_id0 || '/' ||c.ext_cache_id1) as "id",num_reads as "key",  (cache_id) as "value"
	FROM l3d.index_stats as s, l3d.cache as c
	WHERE s.cache_id = c.id
	
	order by "key";
	
END;

$BODY$;

ALTER FUNCTION l3d.get_index_caches_readcounts(refcursor)
    OWNER TO i3dhub;


-- FUNCTION: l3d.get_index_caches_processingtime(refcursor)

-- DROP FUNCTION l3d.get_index_caches_processingtime(refcursor);

CREATE OR REPLACE FUNCTION l3d.get_index_caches_processingtime(
	ocursor refcursor)
RETURNS void
    LANGUAGE 'plpgsql'
    COST 100
    VOLATILE 
AS $BODY$

BEGIN
OPEN ocursor FOR 
	SELECT (c.uuid || '/'|| c.ext_cache_id0 || '/' ||c.ext_cache_id1) as "id" ,  (EXTRACT (EPOCH FROM  (processing_end_date - processing_start_date))) as "key", cache_id as "value"
	FROM l3d.index_stats as s, l3d.cache as c
	WHERE s.cache_id = c.id
	order by "key";
	
END;

$BODY$;

ALTER FUNCTION l3d.get_index_caches_processingtime(refcursor)
    OWNER TO i3dhub;
	
	




-- FUNCTION: l3d.get_index_data(bigint, refcursor)

-- DROP FUNCTION l3d.get_index_data(bigint, refcursor);

CREATE OR REPLACE FUNCTION l3d.get_index_data(
	cid bigint,
	ocursor refcursor)
RETURNS void
    LANGUAGE 'plpgsql'
    COST 100
    VOLATILE 
AS $BODY$

 BEGIN 
OPEN oCursor FOR SELECT row_to_json(d)::text
	FROM (
	SELECT p.properties as properties ,('{"url":"' || c.url || '","state":"'|| c.state || '","group":"' || c.transcoder_group || '","bytes":' || c.bytes::text || '}')::json as cache, 
	c.l3dgen_version as "l3dGenVersion", c.data_layout_version as "dataLayoutVersion", c.original_request as "originalRequest",
	('{"lastModifiedDate": ' || ((extract(epoch from s.last_modified_date))*1000)  || ',"lastReadDate":'||(extract(epoch from s.last_read_date))*1000  ||',"processingStartDate":'||(extract(epoch from s.processing_start_date))*1000  ||',"processingEndDate":'||(extract(epoch from s.processing_end_date))*1000  ||',"queuedDate":'||(extract(epoch from s.queued_date))*1000  ||'}' )::json as "stats", 

	('{"uri":["'|| src.uri || '"], "url": "' || src.url || '", "authUrl": "' || src.auth_url || '", "mimeType": '|| (array_to_json(src.mime_type))::text || ',"property":["' || src.property || '"],"eTag":"\"' || replace(src.e_tag, '"', '\"') ||'\""}')::json as "source"
	--queued_date, num_reads, last_modified_date, last_read_date, processing_start_date, processing_end_date
	FROM l3d.index_cache c,
		l3d.index_properties p,
		l3d.index_source src,
		l3d.index_stats s
	WHERE c.cache_id = p.cache_id
		AND c.cache_id = src.cache_id
		AND c.cache_id = s.cache_id
		AND c.cache_id = cid
	) d;

	END;
	

$BODY$;

ALTER FUNCTION l3d.get_index_data(bigint, refcursor)
    OWNER TO i3dhub;





-- FUNCTION: l3d.get_index_caches_by_waitingtimeinterval(interval, refcursor)

-- DROP FUNCTION l3d.get_index_caches_by_waitingtimeinterval(interval, refcursor);

CREATE OR REPLACE FUNCTION l3d.get_index_caches_by_waitingtimeinterval(
	p_ti interval,
																			
	ocursor refcursor)
RETURNS void
    LANGUAGE 'plpgsql'
    COST 100
    VOLATILE 
AS $BODY$


BEGIN
OPEN ocursor FOR 
	SELECT  src.uri as uri,(processing_start_date - queued_date) as "value"
	FROM l3d.index_source as src, l3d.index_stats as s
	WHERE s.cache_id = src.cache_id
	AND  date_trunc('minutes',(processing_start_date - queued_date)) =p_ti ;
	
END;

$BODY$;

ALTER FUNCTION l3d.get_index_caches_by_waitingtimeinterval(interval,refcursor)
    OWNER TO i3dhub;



-- FUNCTION: l3d.get_index_caches_by_processingtimeinterval(interval, refcursor)

-- DROP FUNCTION l3d.get_index_caches_by_processingtimeinterval(interval, refcursor);

CREATE OR REPLACE FUNCTION l3d.get_index_caches_by_processingtimeinterval(
	p_ti interval,
	ocursor refcursor)
RETURNS void
    LANGUAGE 'plpgsql'
    COST 100
    VOLATILE 
AS $BODY$

BEGIN
OPEN ocursor FOR 
	SELECT  src.uri as uri,(processing_end_date - processing_start_date) as "value"
	FROM l3d.index_source as src, l3d.index_stats as s
	WHERE s.cache_id = src.cache_id
	AND  (processing_end_date - processing_start_date) =p_ti ;
	
END;

$BODY$;

ALTER FUNCTION l3d.get_index_caches_by_processingtimeinterval(interval, refcursor)
    OWNER TO i3dhub;



CREATE OR REPLACE FUNCTION l3d.get_index_caches_by_readcounts(
	p_nr integer,
	ocursor refcursor)
RETURNS void
    LANGUAGE 'plpgsql'
    COST 100
    VOLATILE 
AS $BODY$

BEGIN
OPEN ocursor FOR 
	SELECT  src.uri as uri, num_reads::varchar as "value"
	FROM l3d.index_source as src, l3d.index_stats as s
	WHERE s.cache_id = src.cache_id
	AND  num_reads =p_nr ;
	
END;

$BODY$;

ALTER FUNCTION l3d.get_index_caches_by_readcounts(integer, refcursor)
    OWNER TO i3dhub;
	
	
	
CREATE OR REPLACE FUNCTION l3d.compute_cache_size(
	p_uuid character varying,
	p_cid0 integer,
	p_cid1 integer
	)
RETURNS integer
    LANGUAGE 'plpgsql'
    COST 100
    VOLATILE 
AS $BODY$

	DECLARE cacheId bigint = NULL;
	DECLARE cacheSize integer = NULL;
  BEGIN
  	SELECT l3d.get_cache(p_uuid,p_cid0,p_cid1) INTO cacheId;
	 SELECT COALESCE((
	(SELECT pg_column_size("id")+ pg_column_size(ext_cache_id0)+ pg_column_size(ext_cache_id1)+ pg_column_size(uuid)+ pg_column_size(active)
	FROM l3d.cache
	WHERE "id"=cacheId
	) + (	
	
	--aux node size	
	SELECT SUM(pg_column_size("id")+pg_column_size("aux_node_type_id")+pg_column_size("cache_id")+ pg_column_size("ext_aux_node_id") + pg_column_size("label") )	
	FROM l3d.aux_node
	WHERE "cache_id" = cacheId
	) + (
	-- aux attributes size
	
	SELECT SUM (pg_column_size("key")+pg_column_size("value")+pg_column_size("aux_node_id"))
	FROM l3d.aux_attributes
	WHERE "aux_node_id" IN (
		SELECT "id"
		FROM l3d.aux_node
		WHERE "cache_id" = cacheId
		)
	)+ (
		-- aux Properties 
		SELECT SUM (pg_column_size("aux_value_name_id")+pg_column_size(COALESCE("value_str","value_num"::text)) + pg_column_size("aux_node_id"))
		FROM l3d.aux_value
		WHERE "aux_node_id" IN (
		SELECT "id"
		FROM l3d.aux_node
		WHERE "cache_id" = cacheId
		)
	) + (
	
		-- l3d nodes
		SELECT SUM (pg_column_size("id")+ pg_column_size("ext_node_id")+ pg_column_size("cache_id")+ pg_column_size("label"))
		FROM l3d.node
		WHERE "cache_id" = cacheId
 	) + (
		--l3d nodes metadata1										
		SELECT SUM (pg_column_size("key")+pg_column_size("value_str")+ pg_column_size("node_id"))
		FROM l3d.metadata
		WHERE "node_id" IN (
			SELECT "id"
		    FROM l3d.aux_node
			WHERE "cache_id" = cacheId
		)
	) + (
		-- l3d nodes tags
		COALESCE ((SELECT SUM (pg_column_size("id")+ pg_column_size("node_id")+ pg_column_size("value")+ pg_column_size("tag_name_id"))
		FROM l3d.tags_values 
		WHERE "node_id" IN (
			SELECT "id"
		    FROM l3d.aux_node
			WHERE "cache_id" = cacheId
		)),0)
	) + (
		-- shapes											
		COALESCE ((
			SELECT  SUM (pg_column_size("id")+ pg_column_size ("cache_id")+pg_column_size("ext_shape_id"))
			FROM l3d.shape
		    WHERE "cache_id" = cacheId
		),0)
	) + (
	
		-- faces											
		COALESCE ((
			SELECT  SUM (pg_column_size("id")+ pg_column_size ("cache_id")+pg_column_size("shape_id")+pg_column_size("ext_face_id"))
			FROM l3d.face
		    WHERE "cache_id" = cacheId
		),0)
											
	)									
				
													
	   
	    
),0) INTO cacheSize;

RETURN cacheSize;



 END; 

$BODY$;

ALTER FUNCTION l3d.compute_cache_size(character varying, integer, integer)
    OWNER TO i3dhub;


CREATE OR REPLACE FUNCTION l3d.get_cache_size(
	p_uuid character varying,
	p_cid0 integer,
	p_cid1 integer
	)
RETURNS integer
    LANGUAGE 'plpgsql'
    COST 100
    VOLATILE 
AS $BODY$

 BEGIN
  RETURN 0;
 END; 

$BODY$;

ALTER FUNCTION l3d.get_cache_size(character varying, integer, integer)
    OWNER TO i3dhub;

	
-- FUNCTION: l3d.get_index_cache_times(VARCHAR,INTEGER,INTEGER, refcursor)

-- DROP FUNCTION l3d.get_index_cache_times(VARCHAR,INTEGER,INTEGER, refcursor);

CREATE OR REPLACE FUNCTION l3d.get_index_cache_times(
	cache_uuid VARCHAR,
	cid0 INTEGER,
	cid1 INTEGER,
	ocursor refcursor)
RETURNS void
    LANGUAGE 'plpgsql'
    COST 100
    VOLATILE 
AS $BODY$

BEGIN
OPEN ocursor FOR 
	SELECT  s.last_modified_date as "lastModifiedDate" , s.last_read_date as "lastReadDate", s.queued_date  as "queuedDate", 
			s.processing_start_date as "processingStartDate", s.processing_end_date as "processingEndDate"
	FROM l3d.index_stats as s, l3d.cache as c
	WHERE s.cache_id = c.id
	AND c.uuid = cache_uuid
	AND c.ext_cache_id0 = cid0
	AND c.ext_cache_id1 = cid1
	AND c.active = true
	;
	
END;

$BODY$;

ALTER FUNCTION l3d.get_index_cache_times(VARCHAR,INTEGER,INTEGER, refcursor)
    OWNER TO i3dhub;
