--
-- Script to create instantStatsDB and its tables
--
SET statement_timeout = 0;
SET client_encoding = 'UTF8';
SET standard_conforming_strings = on;
SET check_function_bodies = false;
SET client_min_messages = warning;

--
-- TOC entry 3007 (class 1262 OID 26325)
-- Name: instant3Dhub; Type: DATABASE; Schema: -; Owner: postgres
--

CREATE DATABASE "instantStats" WITH TEMPLATE = template1 ENCODING = '{{ pgsql_locale_encoding }}' LC_COLLATE = '{{ pgsql_lc_collate }}' LC_CTYPE = '{{ pgsql_lc_ctype }}';


ALTER DATABASE "instantStats" OWNER TO i3dhub;

\connect "instantStats"

SET statement_timeout = 0;
SET client_encoding = 'UTF8';
SET standard_conforming_strings = on;
SET check_function_bodies = false;
SET client_min_messages = warning;

--
-- Table public.active_sessions
--
CREATE TABLE public.active_sessions
(
    id bigserial NOT NULL,
    time timestamp with time zone,
    value integer,
    CONSTRAINT pk_active_sessions_id PRIMARY KEY (id)
)
WITH (
    OIDS = FALSE
);

ALTER TABLE public.active_sessions
    OWNER to i3dhub;

--
-- Table public.active_sessions
--
CREATE TABLE public.active_sessions_socket
(
    id bigserial NOT NULL,
    time timestamp with time zone,
    value integer,
    CONSTRAINT pk_active_sessions_socket_id PRIMARY KEY (id)
)
WITH (
    OIDS = FALSE
);

ALTER TABLE public.active_sessions_socket
    OWNER to i3dhub;

    
--
-- Table public.client_devices
--
CREATE TABLE public.client_devices
(
    id bigserial NOT NULL,
    user_agent json,
    vendor json,
    unmasked_vendor json,
    unmasked_renderer json,
    start_time timestamp with time zone,
    support_extensions json,
    stencil_bits json,
    screen json,
    renderer json,
    red_bits json,
    platform json,
    max_view_port_dimensions json,
    max_vertex_texture_image_units json,
    max_vertex_uniform_vectors json,
    max_vertex_attributes json,
    max_varying_vectors json,
    max_texture_size json,
    max_texture_image_units json,
    max_render_buffer_size json,
    max_fragment_uniform_vectors json,
    max_cube_map_texture_size json,
    max_combined_texture_image_units json,
    max_color_buffers json,
    max_anisotropy json,
    green_bits json,
    glsl_version json,
    gl_version json,
    end_time timestamp with time zone,
    depth_bits json,
    context_name json,
    context_attributes json,
    blue_bits json,
    angle_backend json,
    angle json,
    alpha_bits json,
    aliased_point_size_range json,
    aliased_line_width_range json,
    CONSTRAINT pk_client_devices_id PRIMARY KEY (id)
)
WITH (
    OIDS = FALSE
);

ALTER TABLE public.client_devices
    OWNER to i3dhub;


--
-- Table public.expired_sessions_durations
--
CREATE TABLE public.expired_sessions_durations
(
    id bigserial NOT NULL,
    start_time timestamp with time zone,
    end_time timestamp with time zone,
    CONSTRAINT pk_expired_sessions_durations_id PRIMARY KEY (id)
)
WITH (
    OIDS = FALSE
);

ALTER TABLE public.expired_sessions_durations
    OWNER to i3dhub;

--
-- Table public.expired_sessions_durations_socket
--
CREATE TABLE public.expired_sessions_durations_socket
(
    id bigserial NOT NULL,
    start_time timestamp with time zone,
    end_time timestamp with time zone,
    CONSTRAINT pk_expired_sessions_durations_socket_id PRIMARY KEY (id)
)
WITH (
    OIDS = FALSE
);

ALTER TABLE public.expired_sessions_durations_socket
    OWNER to i3dhub;


--
-- Table public.active_sessions_created
--
CREATE TABLE public.active_sessions_created
(
    id bigserial NOT NULL,
    value integer,
    start_time timestamp with time zone,
    end_time timestamp with time zone,
    CONSTRAINT pk_active_sessions_created_id PRIMARY KEY (id)
)
WITH (
    OIDS = FALSE
);

ALTER TABLE public.active_sessions_created
    OWNER to i3dhub;
	


--
-- Table public.client_log
--	
CREATE TABLE public.client_log
(
    id bigserial NOT NULL,
    message character varying,
    time timestamp with time zone,
    CONSTRAINT pk_client_log_id PRIMARY KEY (id)
)
WITH (
    OIDS = FALSE
);

ALTER TABLE public.client_log
    OWNER to i3dhub;
	

CREATE TABLE public.feedback
(
    id bigserial NOT NULL,
	rating integer,
    message character varying,
    time timestamp with time zone,
    CONSTRAINT pk_feedback_id PRIMARY KEY (id)
)
WITH (
    OIDS = FALSE
);

ALTER TABLE public.feedback
    OWNER to i3dhub;		


CREATE TABLE public.job_status
(
    id bigserial NOT NULL,
    time timestamp with time zone,
	open integer,
    closed integer,
    error integer,
    CONSTRAINT pk_job_status_id PRIMARY KEY (id)
)
WITH (
    OIDS = FALSE
);

ALTER TABLE public.job_status
    OWNER to i3dhub;	
    

-- Table: public.features_per_session

-- DROP TABLE public.features_per_session;

CREATE TABLE public.features_per_session
(
    id bigserial NOT NULL,
    expired_sessions_durations_id integer,
    used_features bigint,
    l3d_count integer,
    data_size bigint,
    CONSTRAINT features_per_session_pkey PRIMARY KEY (id),
    CONSTRAINT fk_expired_sessions_durations_id FOREIGN KEY (expired_sessions_durations_id)
        REFERENCES public.expired_sessions_durations (id) MATCH SIMPLE
        ON UPDATE NO ACTION
        ON DELETE NO ACTION
)
WITH (
    OIDS = FALSE
)
TABLESPACE pg_default;

ALTER TABLE public.features_per_session
    OWNER to i3dhub;
    
    
    
-- Table: public.features_per_session_socket

-- DROP TABLE public.features_per_session_socket;

CREATE TABLE public.features_per_session_socket
(
    id bigserial NOT NULL,
    expired_sessions_durations_socket_id integer,
    used_features bigint,
    l3d_count integer,
    data_size bigint,
    CONSTRAINT features_per_session_socket_pkey PRIMARY KEY (id),
    CONSTRAINT fk_expired_sessions_durations_socket_id FOREIGN KEY (expired_sessions_durations_socket_id)
        REFERENCES public.expired_sessions_durations_socket (id) MATCH SIMPLE
        ON UPDATE NO ACTION
        ON DELETE NO ACTION
)
WITH (
    OIDS = FALSE
)
TABLESPACE pg_default;

ALTER TABLE public.features_per_session_socket
    OWNER to i3dhub;


-- Table: public.features_without_session

-- DROP TABLE public.features_without_session;

CREATE TABLE public.features_without_session
(
    id bigserial NOT NULL,
    time timestamp with time zone,
    used_features bigint,
    CONSTRAINT features_usage_news_pkey PRIMARY KEY (id)
)
WITH (
    OIDS = FALSE
)
TABLESPACE pg_default;

ALTER TABLE public.features_without_session
    OWNER to i3dhub;




-- Table: public.index_stats_history

-- DROP TABLE public.index_stats_history;

CREATE TABLE public.index_stats_history
(
    start_time timestamp with time zone,
    end_time timestamp with time zone,
    num_reads integer,
    queued_date timestamp with time zone,
    bytes integer,
    url character varying COLLATE pg_catalog."default",
    id bigserial NOT NULL 
)
WITH (
    OIDS = FALSE
)
TABLESPACE pg_default;

ALTER TABLE public.index_stats_history
    OWNER to i3dhub;
